@@ -1,11 +1,12 @@
 # -*- coding:utf-8 -*-
-
-from fsqlfly.base_handle import BaseHandler, RespCode
+from typing import Optional
+from fsqlfly.base_handle import BaseHandler
 from fsqlfly import settings
+from fsqlfly.common import DBRes
 
 is_login = False
 user = dict(code=200, name='admin', status='ok', currentAuthority='admin', type='password',
-            token=settings.FSQLFLY_TOKEN, success=True)
+            token=settings.FSQLFLY_TOKEN, success=True, deletable=settings.FSQLFLY_SAVE_MODE_DISABLE)
 
 
 class LoginHandler(BaseHandler):
@@ -15,16 +16,21 @@ class LoginHandler(BaseHandler):
         else:
             self.write_json(user)
 
+    @classmethod
+    def is_login(cls, login_type: str, password: Optional[str], token: Optional[str]):
+        if login_type == 'account':
+            return password == settings.FSQLFLY_PASSWORD
+        if login_type == 'token':
+            return token == settings.FSQLFLY_TOKEN
+        return False
+
     def post(self):
-        print(self.request.arguments)
         arg = self.json_body
-        if (arg.get('type') == 'account' and arg.get('password') == settings.FSQLFLY_PASSWORD) or (
-                arg.get('type') == 'token' and arg.get('token') == settings.FSQLFLY_TOKEN
-        ):
+        if self.is_login(arg.get('type'), arg.get('password'), arg.get('type')):
             self.set_login_status()
             self.write_json(user)
         else:
-            self.write_error(RespCode.LoginFail)
+            self.write_res(DBRes.login_error())
 
 
 class LoginOutHandler(BaseHandler):
