@@ -5,12 +5,14 @@ from tornado import ioloop
 from logzero import setup_logger
 from collections import defaultdict
 from typing import Callable, Optional
-from fsqlfly.models import Transform, auto_close
+# from fsqlfly.models import Transform, auto_close
 from requests import Session
 from datetime import datetime, date
 from fsqlfly.workflow import run_transform
-from fsqlfly.settings import FSQLFLY_DEBUG
+from fsqlfly.settings import FSQLFLY_DEBUG, FSQLFLY_MAIL_ENABLE
 from fsqlfly.utils.job_manage import JobControlHandle
+from fsqlfly.contrib.mail import MailHelper
+from fsqlfly.db_helper import DBSession, DBDao
 
 
 def get_log_file(file: str):
@@ -24,15 +26,14 @@ class FlinkJobDaemon:
                  flink_host: str,
                  max_try: int,
                  login_file: str,
-                 max_req_try: int = 5,
-                 stop_handle: Optional[Callable] = None):
+                 max_req_try: int = 5):
         self.logger = get_log_file(login_file)
         self.flink_host = flink_host
         self.max_try = max_try
-        self.stop_handle = stop_handle
         self.max_req_try = max_req_try
         self.session = Session()
         self.run_times = defaultdict(lambda: defaultdict(int))
+        self.started_jobs = set()
 
     def request(self, func: Callable, try_times: int = 0):
         try:
@@ -44,29 +45,37 @@ class FlinkJobDaemon:
             else:
                 return self.request(func, try_times + 1)
 
-    @auto_close
+    @classmethod
+    def send_email(cls, title: str = '', content: str = ''):
+        if FSQLFLY_MAIL_ENABLE:
+            print(MailHelper.send(title, content))
+
     def run(self):
         self.logger.debug('Start Running Flink Job Damon {}'.format(str(datetime.now())[:19]))
 
         today = str(date.today())
         start_time = time.time()
-        query = (Transform.is_publish == True, Transform.is_deleted == False, Transform.is_available == True)
-        job_names = {"{}_{}".format(x.id, x.name): x for x in
-                     Transform.select().where(*query).order_by(Transform.id.desc()).objects()}
+        session = DBSession.get_session()
+        job_names = DBDao.get_job_names(session=session)
 
         living_job = JobControlHandle.live_job_names
         for k, transform in job_names.items():
             if k not in living_job:
                 if self.run_times[today][k] > self.max_try:
                     self.logger.error('job run too many times one day {}'.format(k))
+                    self.send_email('job run too many times one day {}'.format(k))
                 else:
                     self.run_times[today][k] += 1
                     self.logger.info('job {} begin run '.format(k))
                     is_ok, r = run_transform(transform)
                     if not is_ok:
+                        self.send_email('job start fail {}'.format(k), r)
                         self.logger.error(r)
-                    if self.stop_handle:
-                        self.stop_handle(k)
+                    else:
+                        if k in self.started_jobs:
+                            self.send_email('try restart job {}, last fail'.format(k), r)
+                        else:
+                            self.started_jobs.add(k)
 
         end_time = time.time()
 
@@ -74,6 +83,7 @@ class FlinkJobDaemon:
 
         self.logger.debug(
             " ".join([str(datetime.now())[:19], ' damon cost ', '%.2f' % cost, ' second', ' will sleep ']))
+        session.close()
 
     def get_periodic_callback(self, period) -> Callable:
         def _warp():
