@@ -1,5 +1,4 @@
 # -*- coding:utf-8 -*-
-import os
 import sys
 import argparse
 import logzero
@@ -16,9 +15,9 @@ def run_webserver(commands: list):
                                 settings.FSQLFLY_JOB_LOG_FILE)
         extend_command = daemon.get_periodic_callback(settings.FSQLFLY_JOB_DAEMON_FREQUENCY)
         logzero.logger.debug('add job daemon command {}: {}: {}: {}'.format(settings.FSQLFLY_FINK_HOST,
-                                                                        settings.FSQLFLY_JOB_DAEMON_MAX_TRY_ONE_DAY,
-                                                                        settings.FSQLFLY_JOB_LOG_FILE,
-                                                                        settings.FSQLFLY_JOB_DAEMON_FREQUENCY))
+                                                                            settings.FSQLFLY_JOB_DAEMON_MAX_TRY_ONE_DAY,
+                                                                            settings.FSQLFLY_JOB_LOG_FILE,
+                                                                            settings.FSQLFLY_JOB_DAEMON_FREQUENCY))
 
     from fsqlfly.app import run_web
     try:
@@ -27,28 +26,18 @@ def run_webserver(commands: list):
         logzero.logger.info("Stop Web...")
 
 
-def run_canal(commands: list):
-    from fsqlfly.canal_manager.canal_consumer import CanalConsumer
-    CanalConsumer().execute()
-
-
-def run_load_mysql_resource(commands: list):
-    from fsqlfly.canal_manager.load_mysql_resource import LoadMySQLResource
-    LoadMySQLResource().execute()
-
-
 def init_db(commands: list):
-    from fsqlfly.models import create_all_tables
+    from fsqlfly.db_helper import DBDao
 
-    create_all_tables()
+    DBDao.create_all_tables()
 
 
 def reset_db(commands: list):
-    from fsqlfly.models import delete_all_tables
+    from fsqlfly.db_helper import DBDao
     conformed_parser = argparse.ArgumentParser("Conformed")
     conformed_parser.add_argument('-f', '--force', type=bool, default=False, help='force running')
     args = conformed_parser.parse_args(commands)
-    delete_all_tables(force=args.force)
+    DBDao.delete_all_tables(force=args.force)
 
 
 def run_echo_env(commands: list):
@@ -61,14 +50,18 @@ def run_echo_env(commands: list):
     print(open(join(lib_path, 'env.template'), 'r').read(), file=out)
 
 
+def run_canal(commands: list):
+    from fsqlfly.contrib.canal import Consumer
+    Consumer.build(commands[0]).run()
+
+
 def main():
     support_command = {
         "echoenv": run_echo_env,
         "webserver": run_webserver,
         "initdb": init_db,
         "resetdb": reset_db,
-        "loadmysql": run_load_mysql_resource,
-        "canal": run_canal,
+        "runcanal": run_canal
     }
     args = sys.argv[1:]
     method = args[0] if len(args) > 0 else 'help'
